<link href='/static/external/fullcalendar/core/main.min.css' rel='stylesheet' />
<link href='/static/external/fullcalendar/daygrid/main.min.css' rel='stylesheet' />
<link href='/static/external/fullcalendar/list/main.min.css' rel='stylesheet' />
<link href='/static/external/fullcalendar/bootstrap/main.min.css' rel='stylesheet' />
<link href='/static/css/jobcalendar.css' rel='stylesheet' />