{% extends "base.html" %}
{% load i18n %}
{% load config %}
{% block page_title %}
    <h3>
        {% trans "Alle Einsätze im Überblick" %}
    </h3>
{% endblock %}
{% block content %}
{% include 'cal/snippets/content_snippet.html' %}
{% endblock %}

{% block styles %}
{% include 'cal/snippets/styles_snippet.html' %}
{% endblock %}

{% block scripts %}
{% include 'cal/snippets/scripts_snippet.html' %}
{% endblock %}
